@@ -16,12 +16,10 @@ from django.template import RequestContext
 from django.utils.translation import ugettext as _
 from django.views.decorators.csrf import csrf_protect
 
-import settings
-
+from django.conf import settings
 
 logger = logging.getLogger(__name__)
 
-
 def delay_message(remainder):
     """
     A natural-language description of a delay period.
@@ -120,6 +118,7 @@ class Middleware:
         If such is not found, the handlers are not installed.
         """
         try:
+            print "NANANANA"
             config = settings.AUTHENTICATION_THROTTLING
             self.delay_function = config["DELAY_FUNCTION"]
             self.logins = list(config["LOGIN_URLS_WITH_TEMPLATES"])
@@ -129,6 +128,7 @@ class Middleware:
             self.process_request = self._process_request_if_configured
             self.process_response = self._process_response_if_configured
         except:
+            print "HELLO"
             logger.error("Bad AUTHENTICATION_THROTTLING dictionary. "
                            "AuthenticationThrottlingMiddleware disabled.")
 
@@ -149,6 +149,7 @@ class Middleware:
         Block the request if it is a login attempt to which a throttling delay
         is applicable.
         """
+        print "WEEEE"
         if request.method != "POST": return
         for url, template_name in self.logins:
             if request.path[1:] != url: continue
@@ -179,3 +180,4 @@ class Middleware:
             register_authentication_attempt(request)
         return response
 
+__all__ = [delay_message, increment_counters, attempt_count, reset_counters]
